==> tuia-client-0.2.92-20180315.083542-5-sources.jar: cn/com/tuia/advert/model/AdvertDirectDto.java <==
package cn.com.tuia.advert.model;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年08月01日 10:25
 * @descript:
 * @version: 1.0
 */
public class AdvertDirectDto implements Serializable {

    private static final long serialVersionUID = 5499908912752947827L;

    private Long advertId;

    private String advertName;

    private String bannerImageUrl;

    private String promoteURL;

    private Long packageId;
    
    private String materialTitle;
    
    private String materialDes;
    
    private String materialButton;
    
    private Integer advertCouponType;
    
    private Long acgId;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getBannerImageUrl() {
        return bannerImageUrl;
    }

    public void setBannerImageUrl(String bannerImageUrl) {
        this.bannerImageUrl = bannerImageUrl;
    }

    public String getPromoteURL() {
        return promoteURL;
    }

    public void setPromoteURL(String promoteURL) {
        this.promoteURL = promoteURL;
    }

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    
    public String getMaterialTitle() {
        return materialTitle;
    }

    
    public void setMaterialTitle(String materialTitle) {
        this.materialTitle = materialTitle;
    }

    
    public String getMaterialDes() {
        return materialDes;
    }

    
    public void setMaterialDes(String materialDes) {
        this.materialDes = materialDes;
    }

    
    public String getMaterialButton() {
        return materialButton;
    }

    
    public void setMaterialButton(String materialButton) {
        this.materialButton = materialButton;
    }

    
    public Long getAcgId() {
        return acgId;
    }

    
    public void setAcgId(Long acgId) {
        this.acgId = acgId;
    }

    
    public Integer getAdvertCouponType() {
        return advertCouponType;
    }

    
    public void setAdvertCouponType(Integer advertCouponType) {
        this.advertCouponType = advertCouponType;
    }
    
}

==> tuia-client-0.3.8-20180515.091506-2-sources.jar: cn/com/tuia/advert/model/AdvertDirectDto.java <==
package cn.com.tuia.advert.model;

import java.io.Serializable;
import java.util.Map;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年08月01日 10:25
 * @descript:
 * @version: 1.0
 */
public class AdvertDirectDto implements Serializable {

    private static final long serialVersionUID = 5499908912752947827L;

    private Long advertId;

    private String advertName;

    private String bannerImageUrl;

    private String promoteURL;

    private Long packageId;
    
    private String materialTitle;
    
    private String materialDes;
    
    private String materialButton;
    
    private Integer advertCouponType;
    
    private Long acgId;
    
    /**  日志扩展map，仅用于记录日志 */
    private Map<String, String> logExtMap;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public String getBannerImageUrl() {
        return bannerImageUrl;
    }

    public void setBannerImageUrl(String bannerImageUrl) {
        this.bannerImageUrl = bannerImageUrl;
    }

    public String getPromoteURL() {
        return promoteURL;
    }

    public void setPromoteURL(String promoteURL) {
        this.promoteURL = promoteURL;
    }

    public Long getPackageId() {
        return packageId;
    }

    public void setPackageId(Long packageId) {
        this.packageId = packageId;
    }

    
    public String getMaterialTitle() {
        return materialTitle;
    }

    
    public void setMaterialTitle(String materialTitle) {
        this.materialTitle = materialTitle;
    }

    
    public String getMaterialDes() {
        return materialDes;
    }

    
    public void setMaterialDes(String materialDes) {
        this.materialDes = materialDes;
    }

    
    public String getMaterialButton() {
        return materialButton;
    }

    
    public void setMaterialButton(String materialButton) {
        this.materialButton = materialButton;
    }

    
    public Long getAcgId() {
        return acgId;
    }

    
    public void setAcgId(Long acgId) {
        this.acgId = acgId;
    }

    
    public Integer getAdvertCouponType() {
        return advertCouponType;
    }

    
    public void setAdvertCouponType(Integer advertCouponType) {
        this.advertCouponType = advertCouponType;
    }

    
    public Map<String, String> getLogExtMap() {
        return logExtMap;
    }

    
    public void setLogExtMap(Map<String, String> logExtMap) {
        this.logExtMap = logExtMap;
    }
    
}
